<?php

namespace App\Exports;

use App\Models\Reservation;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;

class ReservationsExport implements FromCollection, WithHeadings, WithMapping, WithEvents
{
    public function collection()
    {
        // Fetch all reservations with their related seat data
        return Reservation::with('seat')->get();
    }

    public function headings(): array
    {
        return [
            'Seat',
            'Name',
            'Reserved Guests',
            'Amount to be Paid',
            'Date and Time',
            'Notes',
        ];
    }

    public function map($reservation): array
    {
        return [
            $reservation->seat->name,
            $reservation->full_name,
            $reservation->number_of_guests,
            $reservation->amount_to_pay,
            \Carbon\Carbon::parse($reservation->reservation_date)->format('F j, Y') . ' - ' . \Carbon\Carbon::parse($reservation->estimated_time_arrival)->format('g:i A'),
            $reservation->notes,
        ];
    }

    public function registerEvents(): array
    {
        return [
            AfterSheet::class => function (AfterSheet $event) {
                foreach (range('A', 'F') as $column) { // Adjust for your columns
                    $event->sheet->getDelegate()->getColumnDimension($column)->setAutoSize(true);
                }
            },
        ];
    }
}
