<?php

namespace App\Http\Controllers;

use App\Models\Seat;

use App\Models\Reservation;

use App\Mail\SeatCheckedOut;
use App\Models\SeatSchedule;
use Illuminate\Http\Request;
use App\Mail\CancellationMail;

use Illuminate\Support\Facades\DB;
use App\Mail\SeatStatusNotification;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Mail;

class DashboardController extends Controller
{
    public function index(Request $request)
    {
        // Default to today's date if no reservation date is provided
        $selectedDate = $request->input('reservation_date', now()->toDateString());

        //     // Retrieve the seat data based on seat_id
        // $seat = Seat::find($seat_id);

        $request->session()->put('selectedDate', $selectedDate);

        // // Assuming 'seat_times' is an array or collection of available times for the seat
        // $seat_times = $seat ? $seat->seat_times : [];

        // Fetch all seats with reservations
        $seats = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->get();

        // Fetch individual seats with the same filter logic
        $vvip1 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(1);

        $vvip2 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(2);

        $vvip3 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(3);

        $vvip4 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(4);

        $vip1 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(5);

        $vip2 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(6);

        $vip3 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(7);

        $vip4 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(8);

        $vip5 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(9);

        $vip6 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(10);

        $vip7 = Seat::with(['reservations' => function ($query) use ($selectedDate) {
            $query->where('reservation_date', $selectedDate);
        }])->find(11);

        // Pass the variables to the view
        return view('backend.modules.seats-map-admin.index', compact(
            'seats',
            'selectedDate',
            'vvip1',
            'vvip2',
            'vvip3',
            'vvip4',
            'vip1',
            'vip2',
            'vip3',
            'vip4',
            'vip5',
            'vip6',
            'vip7',

        ));
    }

    public function update_Seat_Status(Request $request)
    {
        $validatedData = $request->validate([
            'seat_id' => 'required|exists:seats,id',
            'seat_status' => 'required|string|in:available,unavailable,occupied',
            'reservation_date' => 'required|date',  // Reservation date for current context
        ]);

        $seatId = $validatedData['seat_id'];
        $status = $validatedData['seat_status'];
        $reservationDate = $validatedData['reservation_date'];  // Single reservation date

        $seat = Seat::findOrFail($seatId);

        if ($status === 'unavailable') {
            SeatSchedule::updateOrCreate(
                ['seat_id' => $seatId, 'date' => $reservationDate],
                ['status' => $status]
            );
        } elseif ($status === 'available') {
            SeatSchedule::updateOrCreate(
                ['seat_id' => $seatId, 'date' => $reservationDate],
                ['status' => $status]
            );
        } elseif ($status === 'occupied') {
            // Explicitly find and update or create the reservation
            $existingReservation = Reservation::where('seat_id', $seatId)
                ->where('reservation_date', $reservationDate)
                ->where('status', 'confirmed')
                ->first();

            $existingReservation->status = $status;
            $existingReservation->save();
        }

        $seat->save();

        $statusMessage = 'Seat schedule updated successfully!';
        return redirect()->back()->with('success', $statusMessage);
    }


    public function status_unavailable(Request $request)
    {
        $validatedData = $request->validate([
            'reservation_date' => 'required|date',  // Reservation date for current context
        ]);

        $reservationDate = $validatedData['reservation_date'];  // Single reservation date

        // Get all seats
        $seats = Seat::all();

        // Loop through all seats and update or create SeatSchedule for each seat
        foreach ($seats as $seat) {
            // Check if there is an existing schedule for this date and seat
            $seatSchedule = SeatSchedule::where('date', $reservationDate)
                ->where('seat_id', $seat->id)
                ->first();

            if ($seatSchedule) {
                // If the status is "unavailable", update it to "available"
                if ($seatSchedule->status === 'unavailable') {
                    $seatSchedule->update(['status' => 'available']);
                } else if ($seatSchedule->status === 'available') {
                    $seatSchedule->update(['status' => 'unavailable']);
                }
            } else {
                // If no schedule exists for this date and seat, create one with "unavailable"
                SeatSchedule::updateOrCreate([
                    'date' => $reservationDate,
                    'seat_id' => $seat->id,
                    'status' => 'unavailable'
                ]);
            }
        }

        $statusMessage = 'Seat schedule updated successfully!';

        return redirect()->back()->with('success', $statusMessage);
    }


    public function updateSeatStatus(Request $request)
    {
        // Validate incoming data
        $validatedData = $request->validate([
            'seat_id' => 'required|exists:seats,id',
            'seat_status' => 'required|string',
            'reservation_date' => 'required|date', // reservation_date is optional
            'seat_fullname' => 'required|string|max:255',
            'seat_email' => 'required|email',
            'seat_contact_number' => 'required|string|max:15',
        ]);

        // Extract the validated data
        $seatId = $validatedData['seat_id'];
        $status = $validatedData['seat_status'];
        $fullName = $validatedData['seat_fullname'];
        $email = $validatedData['seat_email'];
        $contactNumber = $validatedData['seat_contact_number'];

        // Check if reservation_date is provided, else set it to null
        $reservationDate = $validatedData['reservation_date'];


        // Update the confirmation status

        // Conditionally send the email and update reservation/seat statuses
        if ($status === 'check-out') {

            Mail::to($email)->send(new SeatCheckedOut($fullName, $seatId));

            $query = Reservation::where('seat_id', $seatId)
                ->where('status', 'occupied')->where('reservation_date', $reservationDate);


            $reservation = $query->first();


            // Update reservation status
            $reservation->status = 'checked-out';
            $reservation->save();

            // Update the seat status to 'available'
            $seat = Seat::find($seatId);
            if ($seat) {
                $seat->status = 'available';
                $seat->save();
            }
        } elseif ($status === 'cancel') {
            // Send CancellationMail email

            // Find the reservation matching the criteria or fail
            $query = Reservation::where('seat_id', $seatId)
                ->whereIn('status', ['pending', 'confirmed'])
                ->where('reservation_date', $reservationDate);

            $reservation = $query->first();

            if ($reservation) {
                // Retrieve the required information from the reservation
                $email = $reservation->email; // Adjust this field name as per your database structure
                $fullName = $reservation->full_name; // Adjust this field name as per your database structure
                $seat_id = $reservation->seat_id; // Adjust this field name as per your database structure
                $contact_number = $reservation->contact_number; // Adjust this field name as per your database structure
                $reservation_date = $reservation->reservation_date; // Adjust this field name as per your database structure
                $estimated_time_arrival = $reservation->estimated_time_arrival; // Adjust this field name as per your database structure
                $number_of_guests = $reservation->number_of_guests; // Adjust this field name as per your database structure
                $amount_to_pay = $reservation->amount_to_pay; // Adjust this field name as per your database structure
                $door_charge = $reservation->door_charge; // Adjust this field name as per your database structure
                $notes = $reservation->notes; // Adjust this field name as per your database structure

                // Send the cancellation email with detailed information
                Mail::to($email)->send(new CancellationMail(
                    $seat_id,
                    $fullName,
                    $contact_number,
                    $email,
                    $reservation_date,
                    $estimated_time_arrival,
                    $number_of_guests,
                    $amount_to_pay,
                    $door_charge,
                    $notes
                ));

                // Update the reservation status to 'canceled'
                $reservation->status = 'cancelled';
                $reservation->save();

                // Update the seat status to 'available'
                $seat = Seat::find($seatId);
                if ($seat) {
                    $seat->status = 'available';
                    $seat->save();
                }
            }
        }

        // Save the reservation with the updated status
        $reservation->save();

        // Redirect back with a success message
        return redirect()->back()->with('success', 'Seat status updated successfully and email sent!');
    }


    private function updateConfirmationStatus(Reservation $reservation, Request $request)
    {
        // Handle the 'is_confirmed' checkbox
        $isConfirmed = $request->has('is_confirmed') ? true : false;

        // Update the reservation confirmation status
        $reservation->is_confirmed = $isConfirmed;
        $reservation->save();
    }



    public function showSeats(Request $request)
    {
        $reservationDate = $request->input('reservationDate', date('Y-m-d')); // Default to today if no date selected

        // Retrieve seats with reservations filtered by the given reservation date
        $seats = Seat::with(['reservations' => function ($query) use ($reservationDate) {
            $query->whereDate('reservation_date', $reservationDate);
        }])->get();

        // Eager load the seats to pass to the view
        $vvip1 = Seat::find(1);
        $vvip2 = Seat::find(2);
        $vvip3 = Seat::find(3);
        $vvip4 = Seat::find(4);
        $vip1 = Seat::find(5);
        $vip2 = Seat::find(6);
        $vip3 = Seat::find(7);
        $vip4 = Seat::find(8);
        $vip5 = Seat::find(9);
        $vip6 = Seat::find(10);
        $vip7 = Seat::find(11);

        return view('backend.modules.seats-map-admin.index', compact('seats', 'vvip1', 'vvip2', 'vvip3', 'vvip4', 'vip1', 'vip2', 'vip3', 'vip4', 'vip5', 'vip6', 'vip7', 'reservationDate'));
    }
}
