<?php

namespace App\Http\Controllers;

use App\Models\Date;
use App\Models\EventTable;
use App\Models\Seat;
use Illuminate\Console\Scheduling\Event;
use Illuminate\Http\Request;

class EventTableController extends Controller
{
    public function index() {}
    public function show_events($id)
    {
        $event_table = EventTable::where('seat_id', $id)->with('seat', 'date')->paginate(10);

        return view('backend.modules.seats.events', compact('event_table'));
    }

    public function create()
    {
        $seats = Seat::all();
        return view('backend.modules.seats.create', compact('seats'));
    }
    public function store(Request $request)
    {
        $request->validate([
            'seat_id' => 'required|exists:seats,id',
            'date' => 'required|date',
            'price' => 'nullable|string',
            'door_charge' => 'nullable|string',
        ]);

        // Ensure the date exists or create it
        $date = Date::firstOrCreate(['date' => $request->date]);

        // Check if an event already exists with the same seat_id and date_id
        $existingEvent = EventTable::where('seat_id', $request->seat_id)
            ->where('date_id', $date->id)
            ->first();

        if ($existingEvent) {
            return redirect()->route('admin.seats')->with('error', 'Event for this seat and date already exists.');
        }

        // Create the new event if it does not exist
        EventTable::create([
            'seat_id' => $request->seat_id,
            'date_id' => $date->id,
            'price' => $request->price,
            'door_charge' => $request->door_charge,
        ]);

        return redirect()->route('admin.seats')->with('success', 'Event added successfully.');
    }


    public function edit($id)
    {
        $event = EventTable::findOrFail($id);
        
        $seats = Seat::all();
        
        return view('backend.modules.seats.event_edit', compact('event', 'seats'));
    }
    public function update(Request $request, $id)
    {
        $validated = $request->validate([
            'date' => 'required|date',
            'price' => 'nullable|string',
            'door_charge' => 'nullable|string',
            'seat_id' => 'nullable|exists:seats,id',
        ]);

        // Ensure the date exists or create it
        $date = Date::firstOrCreate(['date' => $request->date]);

        $event = EventTable::findOrFail($id);

        $event->update([
            'date_id' => $date->id, // Update the date_id instead of the date
            'price' => $validated['price'],
            'door_charge' => $validated['door_charge'],
            // We are not updating seat_id as it's handled in the form already
        ]);

        return redirect()->route('admin.seats')->with('success', 'Event updated successfully');
    }


    public function delete($id)
    {
        $event_table = EventTable::findOrFail($id);
        $event_table->delete();

        return redirect()->back()->with('success', 'Event deleted successfully.');
    }
}
