<?php

namespace App\Http\Controllers;

use App\Models\Seat;
use Illuminate\Http\Request;

class SeatController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $seats = Seat::all();
        return view('backend.modules.seats.index', compact('seats'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('seats.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validated = $request->validate([
            'name' => 'required|string|max:255',
            'price' => 'required|numeric|min:0',
            'seat_available' => 'required|integer|min:0',
        ]);

        Seat::create($validated);

        return redirect()->route('seats.index')->with('success', 'Seat created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(Seat $seat)
    {
        return view('seats.show', compact('seat'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $seat = Seat::findOrFail($id);
        return view('backend.modules.seats.edit', compact('seat'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'price' => 'required|string',
            'door_charge' => 'required|string',
            'seat_available' => 'required|integer|min:0',
            'show_price' => 'required|in:0,1',
            'time' => 'nullable|string|max:255', // Validate the comma-separated time string
        ]);

        $seat = Seat::findOrFail($id);

        $seat->update([
            'price' => $request->price,
            'door_charge' => $request->door_charge,
            'seat_available' => $request->seat_available,
            'show_price' => $request->show_price,
            'time' => $request->time, // Save the updated time string
        ]);

        return redirect()->route('admin.seats')->with('success', 'Seat updated successfully.');
    }



    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Seat $seat)
    {
        $seat->delete();

        return redirect()->route('seats.index')->with('success', 'Seat deleted successfully.');
    }
}
