<?php

namespace App\Mail;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;
use App\Models\Seat; // Import the Seat model

class CancellationMail extends Mailable
{
    use Queueable, SerializesModels;

    public $fullName;
    public $contactNumber;
    public $email;
    public $reservationDate;
    public $estimatedTimeArrival;
    public $guests;
    public $amountToPay;

    public $door_charge;
    public $notes;
    public $seatName; // To store the seat name

    /**
     * Create a new message instance.
     *
     * @param int $seat_id
     * @param string $fullName
     * @param string $contactNumber
     * @param string $email
     * @param string $reservationDate
     * @param string $estimatedTimeArrival
     * @param int $guests
     * @param string $amountToPay
     * @param string $door_charge
     * @param string|null $notes
     */
    public function __construct(
        $seat_id,
        $fullName,
        $contactNumber,
        $email,
        $reservationDate,
        $estimatedTimeArrival,
        $guests,
        $amountToPay,
        $door_charge,
        $notes = null
    ) {
        $this->fullName = $fullName;
        $this->contactNumber = $contactNumber;
        $this->email = $email;
        $this->reservationDate = $reservationDate;
        $this->estimatedTimeArrival = $estimatedTimeArrival;
        $this->guests = $guests;
        $this->amountToPay = $amountToPay;
        $this->door_charge = $door_charge;
        $this->notes = $notes;

        // Fetch the seat name from the Seat model
        $seat = Seat::find($seat_id);
        $this->seatName = $seat ? $seat->name : 'Unknown Seat'; // Default to 'Unknown Seat' if not found
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        // Construct the email subject using the seat name
        $emailSubject = "XCLV {$this->seatName} Cancellation";

        return $this->view('emails.cancellation')
            ->with([
                'fullName' => $this->fullName,
                'contactNumber' => $this->contactNumber,
                'email' => $this->email,
                'reservationDate' => $this->reservationDate,
                'estimatedTimeArrival' => $this->estimatedTimeArrival,
                'guests' => $this->guests,
                'amountToPay' => $this->amountToPay,
                'door_charge' => $this->door_charge,
                'notes' => $this->notes,
            ])
            ->subject($emailSubject);
    }
}
