<?php

use App\Http\Controllers\BlogsController;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\PageController;
use App\Http\Controllers\SeatController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\ContactUsController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\EventTableController;
use App\Http\Controllers\GalleryController;
use App\Http\Controllers\ReservationController;
use App\Http\Controllers\ReceptionistController;
use App\Models\Blogs;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/




Route::get('/', [PageController::class, 'home']);

Route::get('/about_us', [PageController::class, 'about_us']);
Route::get('/contact_us', [PageController::class, 'contact_us']);
Route::get('/blogs', [PageController::class, 'blogs']);
Route::get('/blogs_details', [PageController::class, 'blogs_details']);
Route::get('/gallery', [PageController::class, 'gallery']);


Route::get('/xclvdvoreservations', [PageController::class, 'reservation'])->name('user.reservation');
Route::post('/reservation/user/success', [ReservationController::class, 'store'])->name('user.reservations.store');
Route::post('/reservation', [PageController::class, 'reservation'])->name('reservations.index');

Route::get('/admin/seats', [SeatController::class, 'index'])->name('admin.seats');
Route::get('/admin/edit/{id}', [SeatController::class, 'edit'])->name('admin.seats.edit');
Route::put('/admin/seats/{id}', [SeatController::class, 'update'])->name('admin.seats.update');

Route::get('/admin/reservation', [ReservationController::class, 'index'])->name('admin.reservation');
Route::patch('admin/reservations/{id}/confirm', [ReservationController::class, 'confirm'])->name('user.reservations.confirm');
Route::delete('admin/reservations/{id}', [ReservationController::class, 'destroy'])->name('user.reservations.destroy');

Route::post('reservation/cancel/{reservation}', [ReservationController::class, 'cancel'])->name('reservation.cancel');

Route::get('/admin/seats/map/admin', [DashboardController::class, 'index'])->name('admin.seats.map');
Route::get('/admin/seats/map/admin/result', [DashboardController::class, 'showSeats'])->name('showSeats');

Route::post('/admin/events/store', [EventTableController::class, 'store'])->name('events.store');
Route::get('/admin/events/create', [EventTableController::class, 'create'])->name('events.create');


Route::get('admin/events/edit/{id}', [EventTableController::class, 'edit'])->name('events.edit_events');
Route::put('admin/events/update/{id}', [EventTableController::class, 'update'])->name('events.update');


Route::get('admin/events/show_events/{id}', [EventTableController::class, 'show_events'])->name('events.show_events');
Route::delete('/events/delete/{id}', [EventTableController::class, 'delete'])->name('events.delete.events');

Route::post('/get-available-times', [PageController::class, 'getAvailableTimes'])->name('get.available.times');

Route::get('admin/seats/map/receptionist', [ReceptionistController::class, 'index'])->name('receptionist.map.show');
Route::post('/reservation/success', [ReceptionistController::class, 'store'])->name('reservations.store');
Route::get('receptionist/reservation', [ReceptionistController::class, 'index'])->name('receptionist.map');

Route::get('reservations/export', [ReservationController::class, 'export'])->name('reservations.export');

Route::get('admin/receptionist', [ReceptionistController::class, 'receptionistLists'])->name('admin.receptionist');
Route::get('admin/receptionist/create', [ReceptionistController::class, 'createReceptionistUser'])->name('admin.receptionist.create');
Route::post('admin/receptionist/create/success', [ReceptionistController::class, 'storeReceptionistUser'])->name('admin.receptionist.store');
Route::get('admin/receptionists/{id}/edit', [ReceptionistController::class, 'edit'])->name('admin.receptionist.edit');
Route::put('admin/receptionists/{id}', [ReceptionistController::class, 'update'])->name('admin.receptionist.update');
Route::delete('admin/receptionists/{id}', [ReceptionistController::class, 'destroy'])->name('admin.receptionist.destroy');
Route::post('/save-form', [ContactUsController::class, 'store'])->name('save.form');

Route::post('/status_unavailable', [DashboardController::class, 'status_unavailable'])->name('status.unavailable');

Route::get('/dashboard', function () {
    return view('dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

Route::middleware('auth')->prefix('admin')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
    Route::resource('/blogs', BlogsController::class);
    Route::resource('/contacts', ContactUsController::class);
    Route::resource('/gallery', GalleryController::class);

    Route::post('/update-seat-status', [DashboardController::class, 'updateSeatStatus'])->name('update.seat.status');
    Route::post('/update_seat_status', [DashboardController::class, 'update_Seat_Status'])->name('update_seat_status');
});

Route::get('/optimize', function () {
    Artisan::call('optimize');
    Artisan::call('route:cache');
    Artisan::call('view:clear');
    Artisan::call('cache:clear');
    return 1;
});

require __DIR__ . '/auth.php';
